@@ -11,7 +11,7 @@ module.exports = {
     },
 
     parserOptions: {
-        parser: 'babel-eslint'
+        parser: '@babel/eslint-parser'
     },
 
     'extends': [
