@@ -3,20 +3,19 @@ package serverObj
 import (
 	"encoding/base64"
 	"fmt"
+	jsoniter "github.com/json-iterator/go"
+	"github.com/tidwall/gjson"
+	"github.com/tidwall/sjson"
+	"github.com/v2rayA/v2rayA/common"
 	"github.com/v2rayA/v2rayA/common/ntp"
+	"github.com/v2rayA/v2rayA/core/coreObj"
+	"github.com/v2rayA/v2rayA/pkg/util/log"
 	"net"
 	"net/url"
 	"regexp"
 	"strconv"
 	"strings"
 	"time"
-
-	jsoniter "github.com/json-iterator/go"
-	"github.com/tidwall/gjson"
-	"github.com/v2rayA/v2rayA/common"
-	"github.com/v2rayA/v2rayA/core/coreObj"
-	"github.com/v2rayA/v2rayA/core/v2ray/service"
-	"github.com/v2rayA/v2rayA/pkg/util/log"
 )
 
 func init() {
@@ -36,9 +35,11 @@ type V2Ray struct {
 	Port          string `json:"port"`
 	ID            string `json:"id"`
 	Aid           string `json:"aid"`
+	Security      string `json:"scy"`
 	Net           string `json:"net"`
 	Type          string `json:"type"`
 	Host          string `json:"host"`
+	SNI           string `json:"sni,omitempty"`
 	Path          string `json:"path"`
 	TLS           string `json:"tls"`
 	Flow          string `json:"flow,omitempty"`
@@ -69,7 +70,8 @@ func ParseVlessURL(vless string) (data *V2Ray, err error) {
 		ID:            u.User.String(),
 		Net:           u.Query().Get("type"),
 		Type:          u.Query().Get("headerType"),
-		Host:          u.Query().Get("sni"),
+		Host:          u.Query().Get("host"),
+		SNI:           u.Query().Get("sni"),
 		Path:          u.Query().Get("path"),
 		TLS:           u.Query().Get("security"),
 		Flow:          u.Query().Get("flow"),
@@ -86,16 +88,13 @@ func ParseVlessURL(vless string) (data *V2Ray, err error) {
 	if data.Type == "" {
 		data.Type = "none"
 	}
-	if data.Host == "" {
-		data.Host = u.Query().Get("host")
-	}
 	if data.TLS == "" {
 		data.TLS = "none"
 	}
 	if data.Flow == "" {
 		data.Flow = "xtls-rprx-direct"
 	}
-	if data.Type == "mkcp" || data.Type == "kcp" {
+	if data.Net == "mkcp" || data.Net == "kcp" {
 		data.Path = u.Query().Get("seed")
 	}
 	return data, nil
@@ -145,6 +144,11 @@ func ParseVmessURL(vmess string) (data *V2Ray, err error) {
 		if aid == "" {
 			aid = q.Get("aid")
 		}
+		security := q.Get("scy")
+		if security == "" {
+			security = q.Get("security")
+		}
+		sni := q.Get("sni")
 		info = V2Ray{
 			ID:            subMatch[1],
 			Add:           subMatch[2],
@@ -152,8 +156,10 @@ func ParseVmessURL(vmess string) (data *V2Ray, err error) {
 			Ps:            ps,
 			Host:          obfsParam,
 			Path:          path,
+			SNI:           sni,
 			Net:           obfs,
 			Aid:           aid,
+			Security:      security,
 			TLS:           map[string]string{"1": "tls"}[q.Get("tls")],
 			AllowInsecure: false,
 		}
@@ -161,16 +167,16 @@ func ParseVmessURL(vmess string) (data *V2Ray, err error) {
 			info.Net = "ws"
 		}
 	} else {
+		// fuzzily parse allowInsecure
+		if allowInsecure := gjson.Get(raw, "allowInsecure"); allowInsecure.Exists() {
+			if newRaw, err := sjson.Set(raw, "allowInsecure", allowInsecure.Bool()); err == nil {
+				raw = newRaw
+			}
+		}
 		err = jsoniter.Unmarshal([]byte(raw), &info)
 		if err != nil {
 			return
 		}
-		if info.Host == "" {
-			sni := gjson.Get(raw, "sni")
-			if sni.Exists() {
-				info.Host = sni.String()
-			}
-		}
 	}
 	// correct the wrong vmess as much as possible
 	if strings.HasPrefix(info.Host, "/") && info.Path == "" {
@@ -199,7 +205,12 @@ func (v *V2Ray) Configuration(info PriorInfo) (c Configuration, err error) {
 		switch strings.ToLower(v.Protocol) {
 		case "vmess":
 			if ok, t, err := ntp.IsDatetimeSynced(); err == nil && !ok {
-				return Configuration{}, fmt.Errorf("please sync datetime first. Your datetime is %v, and the correct datetime is %v", time.Now().Local().Format(ntp.DisplayFormat), t.Local().Format(ntp.DisplayFormat))
+				return Configuration{}, fmt.Errorf("please sync datetime first. Your datetime is %v, and the "+
+					"correct datetime is %v", time.Now().Local().Format(ntp.DisplayFormat), t.Local().Format(ntp.DisplayFormat))
+			}
+			security := v.Security
+			if security == "" {
+				security = "auto"
 			}
 			core.Settings.Vnext = []coreObj.Vnext{
 				{
@@ -209,7 +220,7 @@ func (v *V2Ray) Configuration(info PriorInfo) (c Configuration, err error) {
 						{
 							ID:       id,
 							AlterID:  0,
-							Security: "auto",
+							Security: security,
 						},
 					},
 				},
@@ -236,9 +247,6 @@ func (v *V2Ray) Configuration(info PriorInfo) (c Configuration, err error) {
 		//TODO: QUIC
 		switch strings.ToLower(v.Net) {
 		case "grpc":
-			if err := service.CheckGrpcSupported(); err != nil {
-				return Configuration{}, err
-			}
 			if v.Path == "" {
 				v.Path = "GunService"
 			}
@@ -320,6 +328,8 @@ func (v *V2Ray) Configuration(info PriorInfo) (c Configuration, err error) {
 					Path: v.Path,
 				}
 			}
+		default:
+			return Configuration{}, fmt.Errorf("unexpected transport type: %v", v.Net)
 		}
 		if strings.ToLower(v.TLS) == "tls" {
 			core.StreamSettings.Security = "tls"
@@ -328,7 +338,9 @@ func (v *V2Ray) Configuration(info PriorInfo) (c Configuration, err error) {
 				core.StreamSettings.TLSSettings.AllowInsecure = true
 			}
 			// SNI
-			if v.Host != "" {
+			if v.SNI != "" {
+				core.StreamSettings.TLSSettings.ServerName = v.SNI
+			} else if v.Host != "" {
 				core.StreamSettings.TLSSettings.ServerName = v.Host
 			}
 			// Alpn
@@ -345,6 +357,8 @@ func (v *V2Ray) Configuration(info PriorInfo) (c Configuration, err error) {
 			// SNI
 			if v.Host != "" {
 				core.StreamSettings.XTLSSettings.ServerName = v.Host
+			} else if v.Host != "" {
+				core.StreamSettings.TLSSettings.ServerName = v.Host
 			}
 			if v.AllowInsecure {
 				core.StreamSettings.XTLSSettings.AllowInsecure = true
