@@ -4,7 +4,7 @@ import (
 	"fmt"
 	"github.com/google/gopacket"
 	"github.com/google/gopacket/pcapgo"
-	"github.com/v2fly/v2ray-core/v4/common/strmatcher"
+	"github.com/v2fly/v2ray-core/v5/common/strmatcher"
 	v2router "github.com/v2rayA/v2ray-lib/router"
 	"github.com/v2rayA/v2rayA/common/netTools"
 	"github.com/v2rayA/v2rayA/pkg/util/log"
@@ -50,7 +50,7 @@ type domainHandleResult struct {
 	result handleResult
 }
 
-func (interfaceHandle *handle) handleSendMessage(m *dnsmessage.Message, sAddr, sPort, dAddr, dPort *gopacket.Endpoint, whitelistDomains *strmatcher.MatcherGroup) (ip [4]byte) {
+func (interfaceHandle *handle) handleSendMessage(m *dnsmessage.Message, sAddr, sPort, dAddr, dPort *gopacket.Endpoint, whitelistDomains strmatcher.MatcherGroup) (ip [4]byte) {
 	// dns请求一般只有一个question
 	q := m.Questions[0]
 	if (q.Type != dnsmessage.TypeA && q.Type != dnsmessage.TypeAAAA) ||
@@ -127,10 +127,13 @@ func (interfaceHandle *handle) handleReceiveMessage(m *dnsmessage.Message) (resu
 	return results, msg
 }
 
-func packetFilter(portCache *portCache, pPacket *gopacket.Packet, whitelistDnsServers *v2router.GeoIPMatcher) (m *dnsmessage.Message, pSAddr, pSPort, pDAddr, pDPort *gopacket.Endpoint) {
-	packet := *pPacket
-	trans := packet.TransportLayer()
+func packetFilter(portCache *portCache, packet gopacket.Packet, whitelistDnsServers *v2router.GeoIPMatcher) (m *dnsmessage.Message, pSAddr, pSPort, pDAddr, pDPort *gopacket.Endpoint) {
+	//跳过非网络层的包
+	if packet.NetworkLayer() == nil {
+		return
+	}
 	//跳过非传输层的包
+	trans := packet.TransportLayer()
 	if trans == nil {
 		return
 	}
@@ -179,8 +182,8 @@ func packetFilter(portCache *portCache, pPacket *gopacket.Packet, whitelistDnsSe
 	return &dmessage, &sAddr, &sPort, &dAddr, &dPort
 }
 
-func (interfaceHandle *handle) handlePacket(packet gopacket.Packet, ifname string, whitelistDnsServers *v2router.GeoIPMatcher, whitelistDomains *strmatcher.MatcherGroup) {
-	m, sAddr, sPort, dAddr, dPort := packetFilter(interfaceHandle.portCache, &packet, whitelistDnsServers)
+func (interfaceHandle *handle) handlePacket(packet gopacket.Packet, ifname string, whitelistDnsServers *v2router.GeoIPMatcher, whitelistDomains strmatcher.MatcherGroup) {
+	m, sAddr, sPort, dAddr, dPort := packetFilter(interfaceHandle.portCache, packet, whitelistDnsServers)
 	if m == nil {
 		return
 	}
