@@ -20,6 +20,12 @@ import (
 )
 
 func GetV2rayLocationAssetOverride() string {
+	if assetDir := conf.GetEnvironmentConfig().V2rayAssetsDirectory; assetDir != "" {
+		return assetDir
+	}
+	if assetDir := os.Getenv("V2RAY_LOCATION_ASSET"); assetDir != "" {
+		return assetDir
+	}
 	if runtime.GOOS != "windows" {
 		return filepath.Join(xdg.RuntimeDir, "v2raya")
 	} else {
@@ -118,9 +124,6 @@ func GetGFWListModTime() (time.Time, error) {
 	}
 	return files.GetFileModTime(fullpath)
 }
-func IsCustomExists() bool {
-	return DoesV2rayAssetExist("custom.dat")
-}
 
 func GetConfigBytes() (b []byte, err error) {
 	b, err = os.ReadFile(GetV2rayConfigPath())
