@@ -11,24 +11,25 @@ import (
 	"github.com/v2rayA/v2rayA/pkg/util/log"
 	"sort"
 	"strings"
+	"time"
 )
 
 type Configure struct {
-	Servers          []*ServerRawV2       `json:"servers_v2"`
-	Subscriptions    []*SubscriptionRawV2 `json:"subscriptions_v2"`
-	ConnectedServers []*Which             `json:"connectedServers"`
-	Setting          *Setting             `json:"setting"`
-	Accounts         map[string]string    `json:"accounts"`
-	Ports            Ports                `json:"ports"`
-	InternalDnsList  *string              `json:"internalDnsList"`
-	ExternalDnsList  *string              `json:"externalDnsList"`
-	RoutingA         *string              `json:"routingA"`
+	Servers          []*ServerRaw       `json:"servers"`
+	Subscriptions    []*SubscriptionRaw `json:"subscriptions"`
+	ConnectedServers []*Which           `json:"connectedServers"`
+	Setting          *Setting           `json:"setting"`
+	Accounts         map[string]string  `json:"accounts"`
+	Ports            Ports              `json:"ports"`
+	InternalDnsList  *string            `json:"internalDnsList"`
+	ExternalDnsList  *string            `json:"externalDnsList"`
+	RoutingA         *string            `json:"routingA"`
 }
 
 func New() *Configure {
 	return &Configure{
-		Servers:          make([]*ServerRawV2, 0),
-		Subscriptions:    make([]*SubscriptionRawV2, 0),
+		Servers:          make([]*ServerRaw, 0),
+		Subscriptions:    make([]*SubscriptionRaw, 0),
 		ConnectedServers: make([]*Which, 0),
 		Setting:          NewSetting(),
 		Accounts:         map[string]string{},
@@ -37,7 +38,7 @@ func New() *Configure {
 			Socks5WithPac: 0,
 			Http:          20171,
 			HttpWithPac:   20172,
-			VlessGrpc:     0,
+			Vmess:         0,
 		},
 		InternalDnsList: nil,
 		ExternalDnsList: nil,
@@ -108,19 +109,17 @@ func SetConfigure(cfg *Configure) error {
 }
 
 func RemoveSubscriptions(indexes []int) (err error) {
-	//TODO: separate the SubscriptionRaw and []ServerRaw
-	return db.ListRemove("touch", "subscriptions_v2", indexes)
+	return db.ListRemove("touch", "subscriptions", indexes)
 }
 
 func RemoveServers(indexes []int) (err error) {
-	//TODO: separate the SubscriptionRaw and []ServerRaw
-	return db.ListRemove("touch", "servers_v2", indexes)
+	return db.ListRemove("touch", "servers", indexes)
 }
-func SetServer(index int, server *ServerRawV2) (err error) {
-	return db.ListSet("touch", "servers_v2", index, server)
+func SetServer(index int, server *ServerRaw) (err error) {
+	return db.ListSet("touch", "servers", index, server)
 }
-func SetSubscription(index int, subscription *SubscriptionRawV2) (err error) {
-	return db.ListSet("touch", "subscriptions_v2", index, subscription)
+func SetSubscription(index int, subscription *SubscriptionRaw) (err error) {
+	return db.ListSet("touch", "subscriptions", index, subscription)
 }
 func SetSetting(setting *Setting) (err error) {
 	return db.Set("system", "setting", setting)
@@ -144,11 +143,11 @@ func SetRoutingA(routingA *string) (err error) {
 	return db.Set("system", "routingA", routingA)
 }
 
-func AppendServers(server []*ServerRawV2) (err error) {
-	return db.ListAppend("touch", "servers_v2", server)
+func AppendServers(server []*ServerRaw) (err error) {
+	return db.ListAppend("touch", "servers", server)
 }
-func AppendSubscriptions(subscription []*SubscriptionRawV2) (err error) {
-	return db.ListAppend("touch", "subscriptions_v2", subscription)
+func AppendSubscriptions(subscription []*SubscriptionRaw) (err error) {
+	return db.ListAppend("touch", "subscriptions", subscription)
 }
 
 func IsConfigureNotExists() bool {
@@ -156,14 +155,14 @@ func IsConfigureNotExists() bool {
 	return err != nil || l == 0
 }
 
-func GetServersV2() []ServerRawV2 {
-	r := make([]ServerRawV2, 0)
-	raw, err := db.ListGetAll("touch", "servers_v2")
+func GetServers() []ServerRaw {
+	r := make([]ServerRaw, 0)
+	raw, err := db.ListGetAll("touch", "servers")
 	if err == nil {
 		for _, b := range raw {
-			t, e := Bytes2ServerRaw2(b)
+			t, e := Bytes2ServerRaw(b)
 			if e != nil {
-				log.Warn("GetServersV2: %v", e)
+				log.Warn("GetServers: %v", e)
 				continue
 			}
 			r = append(r, *t)
@@ -172,46 +171,12 @@ func GetServersV2() []ServerRawV2 {
 	return r
 }
 
-// Deprecated
-func GetServers() []ServerRaw {
-	r := make([]ServerRaw, 0)
-	raw, err := db.ListGetAll("touch", "servers")
-	if err == nil {
-		for _, b := range raw {
-			var t ServerRaw
-			e := jsoniter.Unmarshal(b, &t)
-			if e != nil {
-				continue
-			}
-			r = append(r, t)
-		}
-	}
-	return r
-}
-
-//Deprecated
 func GetSubscriptions() []SubscriptionRaw {
 	r := make([]SubscriptionRaw, 0)
 	raw, err := db.ListGetAll("touch", "subscriptions")
 	if err == nil {
 		for _, b := range raw {
-			var t SubscriptionRaw
-			e := jsoniter.Unmarshal(b, &t)
-			if e != nil {
-				continue
-			}
-			r = append(r, t)
-		}
-	}
-	return r
-}
-
-func GetSubscriptionsV2() []SubscriptionRawV2 {
-	r := make([]SubscriptionRawV2, 0)
-	raw, err := db.ListGetAll("touch", "subscriptions_v2")
-	if err == nil {
-		for _, b := range raw {
-			t, e := Bytes2SubscriptionRaw2(b)
+			t, e := Bytes2SubscriptionRaw(b)
 			if e != nil {
 				log.Warn("%v", e)
 				continue
@@ -221,12 +186,12 @@ func GetSubscriptionsV2() []SubscriptionRawV2 {
 	}
 	return r
 }
-func GetSubscriptionV2(index int) *SubscriptionRawV2 {
-	b, err := db.ListGet("touch", "subscriptions_v2", index)
+func GetSubscription(index int) *SubscriptionRaw {
+	b, err := db.ListGet("touch", "subscriptions", index)
 	if err != nil {
 		return nil
 	}
-	s, err := Bytes2SubscriptionRaw2(b)
+	s, err := Bytes2SubscriptionRaw(b)
 	if err != nil {
 		log.Warn("%v", err)
 		return nil
@@ -239,11 +204,6 @@ func GetSettingNotNil() *Setting {
 	b, e := db.GetRaw("system", "setting")
 	if e == nil {
 		_ = jsoniter.Unmarshal(b, r)
-		// migrate
-		if gjson.GetBytes(b, "ipforward").Exists() &&
-			!gjson.GetBytes(b, "portSharing").Exists() {
-			r.PortSharing = r.IpForward
-		}
 	}
 	_ = common.FillEmpty(r, NewSetting())
 	if r.SpecialMode == "" {
@@ -263,7 +223,7 @@ func GetPortsNotNil() *Ports {
 		p.Http = 20171
 		p.Socks5WithPac = 0
 		p.HttpWithPac = 20172
-		p.VlessGrpc = 0
+		p.Vmess = 0
 	}
 	return p
 }
@@ -337,21 +297,21 @@ func GetConnectedServersByOutbound(outbound string) *Whiches {
 }
 
 func GetLenSubscriptions() int {
-	l, err := db.ListLen("touch", "subscriptions_v2")
+	l, err := db.ListLen("touch", "subscriptions")
 	if err != nil {
 		panic(err)
 	}
 	return l
 }
 func GetLenSubscriptionServers(index int) int {
-	b, err := db.ListGet("touch", "subscriptions_v2", index)
+	b, err := db.ListGet("touch", "subscriptions", index)
 	if err != nil {
 		log.Fatal("GetLenSubscriptionServers: %v", err)
 	}
 	return len(gjson.GetBytes(b, "servers").Array())
 }
 func GetLenServers() int {
-	l, err := db.ListLen("touch", "servers_v2")
+	l, err := db.ListLen("touch", "servers")
 	if err != nil {
 		panic(err)
 	}
@@ -432,6 +392,25 @@ func AddOutbound(outbound string) (err error) {
 	return db.SetAdd("outbounds", "names", outbound)
 }
 
+func SetOutboundSetting(outbound string, setting OutboundSetting) (err error) {
+	if _, err := time.ParseDuration(setting.ProbeInterval); err != nil {
+		return err
+	}
+	return db.Set(fmt.Sprintf("outbound.%v", outbound), "setting", setting)
+}
+
+func GetOutboundSetting(outbound string) (setting OutboundSetting) {
+	err := db.Get(fmt.Sprintf("outbound.%v", outbound), "setting", &setting)
+	if err != nil {
+		return OutboundSetting{
+			ProbeURL:      "https://gstatic.com/generate_204",
+			ProbeInterval: "10s",
+			Type:          LeastPing,
+		}
+	}
+	return setting
+}
+
 func RemoveOutbound(outbound string) (err error) {
 	if err = db.BucketClear(fmt.Sprintf("outbound.%v", outbound)); err != nil {
 		return err
