@@ -5,5 +5,5 @@ type Ports struct {
 	Http          int `json:"http"`
 	Socks5WithPac int `json:"socks5WithPac"`
 	HttpWithPac   int `json:"httpWithPac"`
-	VlessGrpc     int `json:"vlessGrpc"`
+	Vmess         int `json:"vmess"`
 }
