@@ -4,7 +4,6 @@ import (
 	"fmt"
 	"github.com/v2rayA/v2rayA/common"
 	"github.com/v2rayA/v2rayA/core/v2ray"
-	"github.com/v2rayA/v2rayA/core/v2ray/service"
 	"net"
 	"net/url"
 	"strconv"
@@ -46,18 +45,9 @@ nextLine:
 			if u, err := url.Parse(dns.Val); err == nil {
 				switch u.Scheme {
 				case "https":
-					if service.CheckDohSupported() != nil {
-						return "", fmt.Errorf("%w: %v", UnsupportedProtocol, u.Scheme)
-					}
 				case "tcp":
-					if strings.HasPrefix(u.Scheme, "tcp") && service.CheckTcpDnsSupported() != nil {
-						return "", fmt.Errorf("%w: %v", UnsupportedProtocol, u.Scheme)
-					}
 				case "quic":
 					// FIXME: after quic:// supported
-					if service.CheckQuicLocalDnsSupported() != nil {
-						return "", fmt.Errorf("%w: %v", UnsupportedProtocol, u.Scheme)
-					}
 				case "":
 					goto invalid
 				default:
