@@ -1,6 +1,7 @@
 package service
 
 import (
+	"bytes"
 	"errors"
 	"fmt"
 	jsoniter "github.com/json-iterator/go"
@@ -139,7 +140,10 @@ func parseSubscriptionUserInfo(str string) SubscriptionUserInfo {
 	}
 	return sui
 }
-
+func trapBOM(fileBytes []byte) []byte {
+	trimmedBytes := bytes.Trim(fileBytes, "\xef\xbb\xbf")
+	return trimmedBytes
+}
 func ResolveSubscriptionWithClient(source string, client *http.Client) (infos []serverObj.ServerObj, status string, err error) {
 	c := *client
 	if c.Timeout < 30*time.Second {
@@ -155,8 +159,8 @@ func ResolveSubscriptionWithClient(source string, client *http.Client) (infos []
 	if err != nil {
 		return nil, "", err
 	}
-	// base64 decode
-	raw, err := common.Base64StdDecode(string(b))
+	// base64 decode. trapBOM due to https://github.com/v2rayA/v2rayA/issues/612
+	raw, err := common.Base64StdDecode(string(trapBOM(b)))
 	if err != nil {
 		raw, _ = common.Base64URLDecode(string(b))
 	}
@@ -195,7 +199,7 @@ func getDataUsageStatus(bytesUsed, bytesRemaining uint64) (status string) {
 }
 
 func UpdateSubscription(index int, disconnectIfNecessary bool) (err error) {
-	subscriptions := configure.GetSubscriptionsV2()
+	subscriptions := configure.GetSubscriptions()
 	addr := subscriptions[index].Address
 	c := httpClient.GetHttpClientAutomatically()
 	resolv.CheckResolvConf()
@@ -205,11 +209,11 @@ func UpdateSubscription(index int, disconnectIfNecessary bool) (err error) {
 		log.Warn("UpdateSubscription: %v: %v", err, subscriptionInfos)
 		return fmt.Errorf("UpdateSubscription: %v", reason)
 	}
-	infoServerRaws := make([]configure.ServerRawV2, len(subscriptionInfos))
+	infoServerRaws := make([]configure.ServerRaw, len(subscriptionInfos))
 	css := configure.GetConnectedServers()
 	cssAfter := css.Get()
 	// serverObj.ServerObj is a pointer(interface), and shouldn't be as a key
-	link2Raw := make(map[string]*configure.ServerRawV2)
+	link2Raw := make(map[string]*configure.ServerRaw)
 	connectedVmessInfo2CssIndex := make(map[string][]int)
 	for i, cs := range css.Get() {
 		if cs.TYPE == configure.SubscriptionServerType && cs.Sub == index {
@@ -224,7 +228,7 @@ func UpdateSubscription(index int, disconnectIfNecessary bool) (err error) {
 	}
 	//将列表更换为新的，并且找到一个跟现在连接的server值相等的，设为Connected，如果没有，则断开连接
 	for i, info := range subscriptionInfos {
-		infoServerRaw := configure.ServerRawV2{
+		infoServerRaw := configure.ServerRaw{
 			ServerObj: info,
 		}
 		link := infoServerRaw.ServerObj.ExportToURL()
@@ -262,7 +266,7 @@ func UpdateSubscription(index int, disconnectIfNecessary bool) (err error) {
 }
 
 func ModifySubscriptionRemark(subscription touch.Subscription) (err error) {
-	raw := configure.GetSubscriptionV2(subscription.ID - 1)
+	raw := configure.GetSubscription(subscription.ID - 1)
 	if raw == nil {
 		return fmt.Errorf("failed to find the corresponding subscription")
 	}
